.. currentmodule:: pvlib

Methods for irradiance calculations
-----------------------------------

.. autosummary::
   :toctree: ../generated/

   pvsystem.PVSystem.get_irradiance
   pvsystem.PVSystem.get_aoi
   pvsystem.PVSystem.get_iam
   tracking.SingleAxisTracker.get_irradiance
